

set -ex



test -f ${PREFIX}/lib/libpython${PKG_VERSION%.*}.a
test -f ${PREFIX}/lib/libpython${PKG_VERSION%.*}.nolto.a
test -f ${PREFIX}/lib/python${PKG_VERSION%.*}/config-${PKG_VERSION%.*}-darwin/libpython${PKG_VERSION%.*}.a
exit 0
